@@ -74,7 +74,7 @@ mKrig.MLE.joint <- function(x, y, weights = rep(1, nrow(x)),
   # if Y is a matrix of replicated data sets use the log likelihood for the complete data sets
   lnProfileLike.max <- -Inf
   temp.fn <- function(parameters) {
-    # Seperate lambda from covariance parameters.
+    # Separate lambda from covariance parameters.
     # Optimization is over log-scale so exponentiate log-parameters.
     lambda = exp(parameters[1])
     if(length(parameters) > 1) {
@@ -172,9 +172,12 @@ mKrig.MLE.joint <- function(x, y, weights = rep(1, nrow(x)),
   }
   
   # save results of the best covariance model evaluation in a neat table
+ 
   summary[1, 1:ncolSummary] <- unlist(c(out$eff.df, out$lnProfileLike.FULL, 
-                                 out$GCV, out$sigma.MLE.FULL, out$rho.MLE.FULL, llambda.opt, 
+                                 out$GCV, out$sigma.MLE.FULL, out$rho.MLE.FULL,
+                                 llambda.opt, 
                                  params.opt, optim.counts))
+  
   if (verbose) {
     cat("Summary: ", 1, summary[1, 1:ncolSummary], fill = TRUE)
   }
