@@ -21,13 +21,13 @@
 
 mKrig.trace <- function(object, iseed, NtrA) {
     set.seed(iseed)
-    # if more tests that number of data points just
-    # find A exactly by np predicts.
+    # if more MonteCarlo samples > number of data points just
+    # find A exactly using  np  calls to predict.
     np<- object$np
     if (NtrA >= object$np) {
         Ey <- diag(1, np)
         NtrA <- np
-        hold <- diag(predict.mKrig(object, ynew = Ey))
+        hold <- diag(predict.mKrig(object, ynew = Ey, collapseFixedEffect=FALSE))
         trA.info<- NA
         trA.est <- sum(hold)
     }
@@ -58,7 +58,7 @@ mKrig.trace <- function(object, iseed, NtrA) {
     )
 }
 
-mKrig.coef <- function(object, y) {
+mKrig.coef <- function(object, y, collapseFixedEffect=TRUE) {
     # given new data y and the matrix decompositions in the
     # mKrig object find coefficients d and c.
     # d are the coefficients for the fixed part
@@ -76,11 +76,21 @@ mKrig.coef <- function(object, y) {
     if( any(is.na(y))){
     	stop("mKrig can not omit missing values in observation vecotor")
     }
+   if( object$nt>0){
     d.coef <- as.matrix(qr.coef(object$qr.VT, forwardsolve(object$Mc, 
         transpose = TRUE, y, upper.tri = TRUE)))
+    d.coefMeans<- rowMeans( d.coef)
+    if( collapseFixedEffect){ 
+      d.coef<- matrix( d.coefMeans, ncol=ncol(d.coef), nrow= nrow( d.coef))
+    }
     #  residuals from subtracting off fixed part
     #  of model as m-1 order polynomial
     resid <- y - object$Tmatrix %*% d.coef
+   }
+  else{
+    d.coef<- NULL
+    resid <- y
+  }
     # and now find c.
     c.coef <- forwardsolve(object$Mc, transpose = TRUE, resid, 
         upper.tri = TRUE)
@@ -108,7 +118,14 @@ print.mKrig <- function(x, digits = 4, ...) {
     }
     
     c1 <- c(c1, "Degree of polynomial null space ( base model):")
-    c2 <- c(c2, x$m - 1)
+    
+    
+    if(x$m !=0 ){
+      c2 <- c(c2, x$m - 1)
+    }
+    else{
+      c2 <- c(c2, NA)
+    }
     c1 <- c(c1, "Total number of parameters in base model")
     c2 <- c(c2, x$nt)
     if (x$nZ > 0) {
@@ -172,7 +189,8 @@ summary.mKrig <- function(object, ...) {
 }
 
 predict.mKrig <- function(object, xnew = NULL, ynew = NULL, grid.list=NULL,
-    derivative = 0, Z = NULL, drop.Z = FALSE, just.fixed = FALSE, 
+    derivative = 0, Z = NULL, drop.Z = FALSE, just.fixed = FALSE,
+    collapseFixedEffect=TRUE, 
     ...) {
     # the main reason to pass new args to the covariance is to increase
     # the temp space size for sparse multiplications
@@ -186,11 +204,12 @@ predict.mKrig <- function(object, xnew = NULL, ynew = NULL, grid.list=NULL,
     if (is.null(xnew)) {
         xnew <- object$x
     }
-    if (is.null(Z)) {
+    if (is.null(Z) & (length(object$ind.drift) >0 )) {
         Z <- object$Tmatrix[, !object$ind.drift]
     }
     if (!is.null(ynew)) {
-        coef.hold <- mKrig.coef(object, ynew)
+        coef.hold <- mKrig.coef(object, ynew,
+                                collapseFixedEffect=collapseFixedEffect)
         c.coef <- coef.hold$c
         d.coef <- coef.hold$d
     }
@@ -200,16 +219,22 @@ predict.mKrig <- function(object, xnew = NULL, ynew = NULL, grid.list=NULL,
     }
     # fixed part of the model this a polynomial of degree m-1
     # Tmatrix <- fields.mkpoly(xnew, m=object$m)
+    # only do this if nt>0, i.e. there is a fixed part.
     #
+    if( object$nt>0){
     if (derivative == 0) {
         if (drop.Z | object$nZ == 0) {
             # just evaluate polynomial and not the Z covariate
-            temp1 <- fields.mkpoly(xnew, m = object$m) %*% d.coef[object$ind.drift, 
-                ]
+            temp1 <- fields.mkpoly(xnew, m = object$m) %*% 
+              d.coef[object$ind.drift, ]
         }
         else {
-            temp1 <- cbind(fields.mkpoly(xnew, m = object$m), 
-                Z) %*% d.coef
+          if( nrow( xnew) != nrow(as.matrix(Z)) ){
+            stop("number of rows of covariate Z is not 
+                 the same as the number of locations")
+          }
+            temp0 <-  cbind(fields.mkpoly(xnew, m = object$m),as.matrix(Z)) 
+            temp1 <- temp0 %*% d.coef
         }
     }
     else {
@@ -222,6 +247,7 @@ predict.mKrig <- function(object, xnew = NULL, ynew = NULL, grid.list=NULL,
     if (just.fixed) {
         return(temp1)
     }
+    }  
     # add nonparametric part. Covariance basis functions
     # times coefficients.
     # syntax is the name of the function and then a list with
@@ -239,5 +265,10 @@ predict.mKrig <- function(object, xnew = NULL, ynew = NULL, grid.list=NULL,
             cov.args))
     }
     # add two parts together and coerce to vector
-    return((temp1 + temp2))
+    if( object$nt>0){
+      return((temp1 + temp2))
+    }
+    else{
+      return(  temp2)
+    }
 }
